SWDEV-249487-remove two HCC related APIs

Change-Id: Icf90ece0808643e0c5f0cc00b6644d5171b553d8
This commit is contained in:
Julia Jiang
2020-09-28 20:13:28 -04:00
committed by Julia Jiang
parent e0be2ca8dd
commit c2a3d19acb
9 changed files with 2 additions and 204 deletions
-5
View File
@@ -1,5 +0,0 @@
#include <hc_am.hpp>
void hipdbPrintMem(void* targetAddress) { hc::am_memtracker_print(targetAddress); };
-35
View File
@@ -2504,41 +2504,6 @@ hipError_t hipProfilerStop() {
return ihipLogStatus(hipSuccess);
};
//-------------------------------------------------------------------------------------------------
//-------------------------------------------------------------------------------------------------
// HCC-specific accessor functions:
//---
hipError_t hipHccGetAccelerator(int deviceId, hc::accelerator* acc) {
HIP_INIT_API(hipHccGetAccelerator, deviceId, acc);
const ihipDevice_t* device = ihipGetDevice(deviceId);
hipError_t err;
if (device == NULL) {
err = hipErrorInvalidDevice;
} else {
*acc = device->_acc;
err = hipSuccess;
}
return ihipLogStatus(err);
}
//---
hipError_t hipHccGetAcceleratorView(hipStream_t stream, hc::accelerator_view** av) {
HIP_INIT_API(hipHccGetAcceleratorView, stream, av);
if (stream == hipStreamNull) {
ihipCtx_t* device = ihipGetTlsDefaultCtx();
stream = device->_defaultStream;
}
*av = stream->locked_getAv(); // TODO - review.
hipError_t err = hipSuccess;
return ihipLogStatus(err);
}
//// TODO - add identifier numbers for streams and devices to help with debugging.
// TODO - add a contect sequence number for debug. Print operator<< ctx:0.1 (device.ctx)